@@ -17,7 +17,7 @@
 
 """setuptools plugin for projects maintained under Bazaar."""
 
-__version__ = '1.2'
+__version__ = '2.0'
 __all__ = [
     'find_files_for_bzr',
     ]
@@ -44,13 +44,16 @@ def bzrlib_get_children(path):
     load_plugins()
     # Open an existing branch which contains the url.
     branch, inpath = Branch.open_containing(path)
-    # Get the inventory of the branch's last revision.
-    inv = branch.repository.get_revision_inventory(branch.last_revision())
-    # Get the inventory entry for the path.
-    entry = inv[inv.path2id(path)]
-    # Return the names of the children.
-    return [os.path.join(path, child) for child in entry.children.keys()]
-
+    branch.lock_read()
+    try:
+        # Get the inventory of the branch's last revision.
+        inv = branch.repository.get_revision_inventory(branch.last_revision())
+        # Get the inventory entry for the path.
+        entry = inv[inv.path2id(path)]
+        # Return the names of the children.
+        return [os.path.join(path, child) for child in entry.children.keys()]
+    finally:
+        branch.unlock()
 
 def bzrlib_find_files_for_bzr(dirname):
     """Use direct bzrlib calls to recursively find versioned files."""
